@@ -43,6 +43,7 @@ from zope.schema.fieldproperty import FieldProperty
 from pyams_file.interfaces import FileModifiedEvent, IAudioFile, IBlobReferenceManager, IFile, \
     IFileInfo, IImageFile, ISVGImageFile, IVideoFile
 from pyams_utils.adapter import ContextAdapter, adapter_config
+from pyams_utils.factory import factory_config
 from pyams_utils.registry import get_utility
 from pyams_utils.request import check_request
 
@@ -126,7 +127,7 @@ EXTENSIONS_THUMBNAILS = {
 # Blobs references manager utility
 #
 
-@implementer(IBlobReferenceManager)
+@factory_config(IBlobReferenceManager)
 class BlobReferencesManager(Persistent, Contained):
     """Global blobs references manager utility
 
@@ -276,7 +277,11 @@ class File(Persistent, Contained):
         return self.get_blob(mode='r')
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        pass
+        """Context manager exit point
+
+        We don't close the blob here.
+        It's up to the context manager call to close it!
+        """
 
     def __iter__(self):
         """Iterator over blob content to read by chunks"""
@@ -307,7 +312,7 @@ def handle_removed_file(event):
     event.object.remove_blob_reference()
 
 
-@adapter_config(context=IFile, provides=ICopyHook)
+@adapter_config(required=IFile, provides=ICopyHook)
 class BlobFileCopyHook(ContextAdapter):
     """Blob file copy hook
 
